'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createRenderer;
exports._createShallowRenderer = _createShallowRenderer;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactTestRenderer = require('react-test-renderer');

var _reactTestRenderer2 = _interopRequireDefault(_reactTestRenderer);

var _reactAddonsTestUtils = require('react-addons-test-utils');

var _reactAddonsTestUtils2 = _interopRequireDefault(_reactAddonsTestUtils);

var _utils = require('./utils');

var _renderer = require('./renderer');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createRenderer(Target, props) {
  var deep = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

  if (typeof props === 'boolean') {
    deep = props;
    props = undefined;
  }

  if (deep === false) {
    return _createShallowRenderer(Target, props);
  }

  var tree = void 0;
  var instance = void 0;

  if ((0, _utils.isClass)(Target)) {
    instance = _reactTestRenderer2.default.create(_react2.default.createElement(Target, props));
  } else if ((0, _utils.isTree)(Target)) {
    tree = Target;
  } else if ((0, _utils.isElement)(Target)) {
    instance = _reactTestRenderer2.default.create(Target);
  } else if ((0, _utils.isInstance)(Target)) {
    instance = Target; // note: createApp() always provides an instance
  } else {
    tree = Target;
  }

  return new _renderer.DeepRenderer(instance, tree);
}

function _createShallowRenderer(Target, props) {
  var renderer = _reactAddonsTestUtils2.default.createRenderer();

  var tree = void 0;
  var element = void 0;

  if ((0, _utils.isClass)(Target)) {
    element = _react2.default.createElement(Target, props);
    renderer.render(element);
  } else if ((0, _utils.isTree)(Target)) {
    tree = Target;
  } else if ((0, _utils.isElement)(Target)) {
    element = Target;
    renderer.render(element);
  } else {
    tree = Target;
  }

  return new _renderer.ShallowRenderer(renderer, element, tree);
}

// ReactTestUtils does not create component instances that play nice with Jest mocks.
// A mocked component passed to ReactTestUtils.createRenderer().render(component)
// will expect there to be no props passed, which defeats its purpose.

var originalError = global.console.error.bind(global.console);

global.console.error = function () {
  var msg = arguments.length <= 0 ? undefined : arguments[0];
  if (msg && msg.indexOf('Unknown prop') > -1) {
    return;
  }

  return originalError.apply(undefined, arguments);
};