'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DeepRenderer = DeepRenderer;
exports.ShallowRenderer = ShallowRenderer;

var _utils = require('./utils');

function DeepRenderer(instance, tree) {
  this._instance = instance;
  this._tree = tree;
}

DeepRenderer.prototype = {
  // calling tree() insures having up to date instance in response to state changes
  tree: function tree() {
    return (0, _utils.isInstance)(this._instance) ? this._instance.toJSON() : this._tree;
  },


  // calling snap will of course also use most up to date instance
  snap: function snap() {
    expect(this.tree()).toMatchSnapshot();
    return this;
  },


  // this._instance can be passed to snap(renderer.instance()) -- this is as opposed to doing this.snap()
  component: function component() {
    return this._instance;
  }
};

function ShallowRenderer(renderer, element, tree) {
  this._renderer = renderer;
  this._element = element;
  this._tree = tree;
}

ShallowRenderer.prototype = {
  tree: function tree() {
    return this._element ? this._renderer.getRenderOutput() : this._tree;
  },
  snap: function snap() {
    expect(this.tree()).toMatchSnapshot();
    return this;
  },
  component: function component() {
    return this._element;
  }
};